@@ -17,13 +17,14 @@
 
 package org.apache.seatunnel.flink.util;
 
+import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.flink.enums.FormatType;
 
 import org.apache.seatunnel.shade.com.typesafe.config.Config;
 import org.apache.seatunnel.shade.com.typesafe.config.ConfigValue;
 
-import com.alibaba.fastjson.JSONArray;
-import com.alibaba.fastjson.JSONObject;
+import com.fasterxml.jackson.databind.node.ArrayNode;
+import com.fasterxml.jackson.databind.node.ObjectNode;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.java.typeutils.ObjectArrayTypeInfo;
@@ -58,19 +59,19 @@ public final class SchemaUtil {
 
         switch (format) {
             case JSON:
-                getJsonSchema(schema, (JSONObject) info);
+                getJsonSchema(schema, (ObjectNode) info);
                 break;
             case CSV:
                 getCsvSchema(schema, (List<Map<String, String>>) info);
                 break;
             case ORC:
-                getOrcSchema(schema, (JSONObject) info);
+                getOrcSchema(schema, (ObjectNode) info);
                 break;
             case AVRO:
-                getAvroSchema(schema, (JSONObject) info);
+                getAvroSchema(schema, (ObjectNode) info);
                 break;
             case PARQUET:
-                getParquetSchema(schema, (JSONObject) info);
+                getParquetSchema(schema, (ObjectNode) info);
                 break;
             default:
         }
@@ -110,9 +111,9 @@ public final class SchemaUtil {
         return formatDescriptor;
     }
 
-    private static void getJsonSchema(Schema schema, JSONObject json) {
-
-        for (Map.Entry<String, Object> entry : json.entrySet()) {
+    private static void getJsonSchema(Schema schema, ObjectNode json) {
+        Map<String, Object> jsonMap = JsonUtils.toMap(json);
+        for (Map.Entry<String, Object> entry : jsonMap.entrySet()) {
             String key = entry.getKey();
             Object value = entry.getValue();
             if (value instanceof String) {
@@ -123,12 +124,12 @@ public final class SchemaUtil {
                 schema.field(key, Types.LONG());
             } else if (value instanceof BigDecimal) {
                 schema.field(key, Types.JAVA_BIG_DEC());
-            } else if (value instanceof JSONObject) {
-                schema.field(key, getTypeInformation((JSONObject) value));
-            } else if (value instanceof JSONArray) {
-                Object obj = ((JSONArray) value).get(0);
-                if (obj instanceof JSONObject) {
-                    schema.field(key, ObjectArrayTypeInfo.getInfoFor(Row[].class, getTypeInformation((JSONObject) obj)));
+            } else if (value instanceof ObjectNode) {
+                schema.field(key, getTypeInformation((ObjectNode) value));
+            } else if (value instanceof ArrayNode) {
+                Object obj = ((ArrayNode) value).get(0);
+                if (obj instanceof ObjectNode) {
+                    schema.field(key, ObjectArrayTypeInfo.getInfoFor(Row[].class, getTypeInformation((ObjectNode) obj)));
                 } else {
                     schema.field(key, ObjectArrayTypeInfo.getInfoFor(Object[].class, TypeInformation.of(Object.class)));
                 }
@@ -161,7 +162,7 @@ public final class SchemaUtil {
      * @param schema schema
      * @param json   json
      */
-    private static void getOrcSchema(Schema schema, JSONObject json) {
+    private static void getOrcSchema(Schema schema, ObjectNode json) {
 
     }
 
@@ -171,11 +172,11 @@ public final class SchemaUtil {
      * @param schema schema
      * @param json   json
      */
-    private static void getParquetSchema(Schema schema, JSONObject json) {
+    private static void getParquetSchema(Schema schema, ObjectNode json) {
 
     }
 
-    private static void getAvroSchema(Schema schema, JSONObject json) {
+    private static void getAvroSchema(Schema schema, ObjectNode json) {
         RowTypeInfo typeInfo = (RowTypeInfo) AvroSchemaConverter.<Row>convertToTypeInfo(json.toString());
         String[] fieldNames = typeInfo.getFieldNames();
         for (String name : fieldNames) {
@@ -183,12 +184,13 @@ public final class SchemaUtil {
         }
     }
 
-    public static RowTypeInfo getTypeInformation(JSONObject json) {
+    public static RowTypeInfo getTypeInformation(ObjectNode json) {
         int size = json.size();
         String[] fields = new String[size];
         TypeInformation<?>[] informations = new TypeInformation[size];
+        Map<String, Object> jsonMap = JsonUtils.toMap(json);
         int i = 0;
-        for (Map.Entry<String, Object> entry : json.entrySet()) {
+        for (Map.Entry<String, Object> entry : jsonMap.entrySet()) {
             String key = entry.getKey();
             Object value = entry.getValue();
             fields[i] = key;
@@ -200,10 +202,10 @@ public final class SchemaUtil {
                 informations[i] = Types.LONG();
             } else if (value instanceof BigDecimal) {
                 informations[i] = Types.JAVA_BIG_DEC();
-            } else if (value instanceof JSONObject) {
-                informations[i] = getTypeInformation((JSONObject) value);
-            } else if (value instanceof JSONArray) {
-                JSONObject demo = ((JSONArray) value).getJSONObject(0);
+            } else if (value instanceof ObjectNode) {
+                informations[i] = getTypeInformation((ObjectNode) value);
+            } else if (value instanceof ArrayNode) {
+                ObjectNode demo = (ObjectNode) ((ArrayNode) value).get(0);
                 informations[i] = ObjectArrayTypeInfo.getInfoFor(Row[].class, getTypeInformation(demo));
             }
             i++;
