@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.common.config;
 
+import java.io.File;
 import java.net.URISyntaxException;
 import java.nio.file.Path;
 import java.nio.file.Paths;
@@ -32,7 +33,7 @@ public class Common {
     }
 
     private static final List<String> ALLOWED_MODES = Arrays.stream(DeployMode.values())
-        .map(DeployMode::getName).collect(Collectors.toList());
+            .map(DeployMode::getName).collect(Collectors.toList());
 
     private static Optional<String> MODE = Optional.empty();
 
@@ -67,6 +68,7 @@ public class Common {
         if (MODE.equals(Optional.of(DeployMode.CLIENT.getName()))) {
             try {
                 String path = Common.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath();
+                path = new File(path).getPath();
                 return Paths.get(path).getParent().getParent();
             } catch (URISyntaxException e) {
                 throw new RuntimeException(e);
@@ -89,6 +91,27 @@ public class Common {
         return Paths.get(appRootDir().toString(), "plugins");
     }
 
+    /**
+     * Plugin Root Dir
+     */
+    public static Path connectorRootDir(String engine) {
+        return Paths.get(appRootDir().toString(), "connectors", engine.toLowerCase());
+    }
+
+    /**
+     * Plugin Connector Jar Dir
+     */
+    public static Path connectorJarDir(String engine) {
+        return Paths.get(appRootDir().toString(), "connectors", engine.toLowerCase());
+    }
+
+    /**
+     * Plugin Connector Dir
+     */
+    public static Path connectorDir() {
+        return Paths.get(appRootDir().toString(), "connectors");
+    }
+
     public static Path pluginTarball() {
         return appRootDir().resolve("plugins.tar.gz");
     }
