@@ -25,15 +25,31 @@ if [ -f "${CONF_DIR}/seatunnel-env.sh" ]; then
     . "${CONF_DIR}/seatunnel-env.sh"
 fi
 
-CMD=$(java -cp ${APP_JAR} org.apache.seatunnel.FlinkStarter ${@}) && EXIT_CODE=$? || EXIT_CODE=$?
+if [ $# == 0 ]
+then
+    args="-h"
+else
+    args=$@
+fi
+
+ENV_PARAMETERS_OR_ERROR=$(java -cp ${APP_JAR} org.apache.seatunnel.core.flink.FlinkEnvParameterParser ${args}) && EXIT_CODE=$? || EXIT_CODE=$?
+if [ ${EXIT_CODE} -eq 0 ]; then
+  echo "Export JVM_ARGS: ${ENV_PARAMETERS_OR_ERROR}"
+  export JVM_ARGS="${ENV_PARAMETERS_OR_ERROR}"
+else
+    echo "${ENV_PARAMETERS_OR_ERROR}"
+    exit ${EXIT_CODE}
+fi
+
+CMD=$(java -cp ${APP_JAR} org.apache.seatunnel.core.flink.FlinkStarter ${args}) && EXIT_CODE=$? || EXIT_CODE=$?
 if [ ${EXIT_CODE} -eq 234 ]; then
     # print usage
-    echo ${CMD}
+    echo "${CMD}"
     exit 0
 elif [ ${EXIT_CODE} -eq 0 ]; then
     echo "Execute SeaTunnel Flink Job: ${CMD}"
     eval ${CMD}
 else
-    echo ${CMD}
+    echo "${CMD}"
     exit ${EXIT_CODE}
 fi
