@@ -24,14 +24,22 @@ if [ -f "${CONF_DIR}/seatunnel-env.sh" ]; then
     . "${CONF_DIR}/seatunnel-env.sh"
 fi
 
-CMD=$(java -cp ${APP_JAR} org.apache.seatunnel.SparkStarter ${@}) && EXIT_CODE=$? || EXIT_CODE=$?
+if [ $# == 0 ]
+then
+    args="-h"
+else
+    args=$@
+fi
+
+CMD=$(java -cp ${APP_JAR} org.apache.seatunnel.core.spark.SparkStarter ${args}) && EXIT_CODE=$? || EXIT_CODE=$?
 if [ ${EXIT_CODE} -eq 234 ]; then
     # print usage
-    echo ${CMD}
+    echo "${CMD}"
     exit 0
 elif [ ${EXIT_CODE} -eq 0 ]; then
-    eval ${CMD}
+    echo "Execute SeaTunnel Spark Job: $(echo ${CMD} | tail -n 1)"
+    eval $(echo ${CMD} | tail -n 1)
 else
-    echo ${CMD}
+    echo "${CMD}"
     exit ${EXIT_CODE}
 fi
